package com.ruoyi.web.controller.invest;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.enums.FileType;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.invest.domain.TProjectCirculation;
import com.ruoyi.invest.domain.TProjectCompany;
import com.ruoyi.invest.domain.TProjectContacts;
import com.ruoyi.invest.domain.TProjectPool;
import com.ruoyi.invest.service.ITProjectCirculationService;
import com.ruoyi.invest.service.ITProjectCompanyService;
import com.ruoyi.invest.service.ITProjectContactsService;
import com.ruoyi.invest.service.ITProjectPoolService;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.tool.domain.TUnifyFile;
import com.ruoyi.tool.service.ITUnifyFileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 项目池Controller
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
@Api(tags = "项目池")
@RestController
@RequestMapping("/invest/pool")
public class TProjectPoolController extends BaseController
{
    @Autowired
    private ITProjectPoolService tProjectPoolService;

    @Autowired
    private ITProjectCompanyService tProjectCompanyService;

    @Autowired
    private ITProjectContactsService tProjectContactsService;

    @Autowired
    private ITProjectCirculationService tProjectCirculationService;

    @Autowired
    private ITUnifyFileService tUnifyFileService;

    @Autowired
    private ISysDictDataService dictDataService;

    /**
     * 查询项目池列表
     */
    @ApiOperation("查询项目池列表")
    @PreAuthorize("@ss.hasPermi('invest:pool:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectPool tProjectPool)
    {
        startPage();
        List<TProjectPool> list = tProjectPoolService.selectTProjectPoolList(tProjectPool);
        return getDataTable(list);
    }

    /**
     * 导出项目池列表
     */
    @ApiOperation("导出项目池列表")
    @PreAuthorize("@ss.hasPermi('invest:pool:export')")
    @Log(title = "项目池", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectPool tProjectPool)
    {
        List<TProjectPool> list = tProjectPoolService.selectTProjectPoolList(tProjectPool)
                .stream().map(n -> {
                    n.setChannel(n.gettProjectChannel().getChannelName());
                    n.setIndustry(dictDataService.selectDictLabel("CUSTOMER_TRADE",n.getIndustry()));
                    n.setCompany(n.gettProjectCompany().getCompanyName());
                    n.setProjectContacts(n.gettProjectContacts().getName());
                    n.setInvestType(dictDataService.selectDictLabel("INVEST_TYPE",n.getInvestType()));
                    n.setInvestPloy(dictDataService.selectDictLabel("INVEST_PLOY",n.getInvestPloy()));
                    n.setInvestWorth(dictDataService.selectDictLabel("INVEST_WORTH",n.getInvestWorth()));
                    n.setProjectStage(dictDataService.selectDictLabel("PROJECT_STAGE",n.getProjectStage()));
                    n.setProjectState(dictDataService.selectDictLabel("PROJECT_STATE",n.getProjectState()));
                    return n;
                })
                .collect(Collectors.toList());
        ExcelUtil<TProjectPool> util = new ExcelUtil<TProjectPool>(TProjectPool.class);
        util.exportExcel(response, list, "项目池数据");
    }

    /**
     * 获取项目池详细信息
     */
    @ApiOperation("获取项目池详细信息")
    @PreAuthorize("@ss.hasPermi('invest:pool:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectPoolService.selectTProjectPoolById(id));
    }

    /**
     * 新增项目池
     */
    @ApiOperation("新增项目池")
    @PreAuthorize("@ss.hasPermi('invest:pool:add')")
    @Log(title = "项目池", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectPool tProjectPool)
    {
        tProjectPool.setCreateBy(getNickName());
        tProjectPool.setId(IdUtils.fastSimpleUUID());
        TProjectCompany tProjectCompany = tProjectPool.gettProjectCompany();
        tProjectCompany.setCreateBy(getNickName());
        tProjectCompany.setId(IdUtils.fastSimpleUUID());
        TProjectContacts tProjectContacts = tProjectPool.gettProjectContacts();
        tProjectContacts.setCreateBy(getNickName());
        tProjectContacts.setId(IdUtils.fastSimpleUUID());
        // todo 设置项目联系人
        tProjectPool.setProjectContacts(tProjectContacts.getId());
        // todo 设置公司信息关联关系
        tProjectCompany.setProjectPoolId(tProjectPool.getId());
        // todo 保存附件信息
        List<TUnifyFile> tUnifyFileList = tProjectPool.getListFile();
        if(!tUnifyFileList.isEmpty()){
            for (TUnifyFile tUnifyFile:
                    tUnifyFileList) {
                tUnifyFile.setFileId(tProjectPool.getId());
                tUnifyFile.setFileBusinessId(tProjectCompany.getId());//公司ID
                tUnifyFile.setUploadType(String.valueOf(FileType.COMPANY.ordinal()));//文件类型:公司信息
                tUnifyFile.setCreateBy(getNickName());
                tUnifyFileService.insertTUnifyFile(tUnifyFile);
            }
        }

        tProjectCompanyService.insertTProjectCompany(tProjectCompany);
        tProjectContactsService.insertTProjectContacts(tProjectContacts);
        // todo 增加项目创建记录
        TProjectCirculation tProjectCirculation = new TProjectCirculation();
        tProjectCirculation.setProjectPoolId(tProjectPool.getId());
        tProjectCirculation.setStageName("项目报备");
        tProjectCirculation.setCreateBy(getNickName());
        tProjectCirculationService.insertTProjectCirculation(tProjectCirculation);

        return toAjax(tProjectPoolService.insertTProjectPool(tProjectPool));
    }

    /**
     * 修改项目池
     */
    @ApiOperation("修改项目池")
    @PreAuthorize("@ss.hasPermi('invest:pool:edit')")
    @Log(title = "项目池", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectPool tProjectPool)
    {
        tProjectPool.setUpdateBy(getNickName());
        TProjectCompany tProjectCompany = tProjectPool.gettProjectCompany();
        tProjectCompany.setUpdateBy(getNickName());
        TProjectContacts tProjectContacts = tProjectPool.gettProjectContacts();
        tProjectContacts.setUpdateBy(getNickName());
        tProjectContacts.setId(tProjectPool.getProjectContacts());
        // 上传并返回新文件名称
        // todo 保存附件信息
        List<TUnifyFile> tUnifyFileList = tProjectPool.getListFile();
        if(!tUnifyFileList.isEmpty()){
            for (TUnifyFile tUnifyFile:tUnifyFileList) {
                if(tUnifyFile.getId() == null){
                    tUnifyFile.setFileId(tProjectPool.getId());
                    tUnifyFile.setFileBusinessId(tProjectCompany.getId());//公司ID
                    tUnifyFile.setUploadType(String.valueOf(FileType.COMPANY.ordinal()));//文件类型:公司信息
                    tUnifyFile.setCreateBy(getNickName());
                    tUnifyFileService.insertTUnifyFile(tUnifyFile);
                }
            }
        }
        tProjectCompanyService.updateTProjectCompany(tProjectCompany);
        tProjectContactsService.updateTProjectContacts(tProjectContacts);
        return toAjax(tProjectPoolService.updateTProjectPool(tProjectPool));
    }

    /**
     * 删除项目池
     */
    @ApiOperation("删除项目池")
    @PreAuthorize("@ss.hasPermi('invest:pool:remove')")
    @Log(title = "项目池", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tProjectPoolService.updateTProjectPoolByIds(ids));
    }

    /**
     * 修改项目池状态
     */
    @ApiOperation("修改项目池状态")
    @PreAuthorize("@ss.hasPermi('invest:pool:edit')")
    @Log(title = "项目池", businessType = BusinessType.UPDATE)
    @PutMapping("/editStage")
    public AjaxResult editStage(@RequestBody TProjectPool tProjectPool)
    {
        tProjectPool.setUpdateBy(getNickName());
        // todo 增加项目创建记录
        TProjectCirculation tProjectCirculation = new TProjectCirculation();
        tProjectCirculation.setProjectPoolId(tProjectPool.getId());
        tProjectCirculation.setStageName(tProjectPool.getStageName());
        tProjectCirculation.setCreateBy(getNickName());
        tProjectCirculationService.insertTProjectCirculation(tProjectCirculation);

        return toAjax(tProjectPoolService.updateTProjectPool(tProjectPool));
    }

}
